@@ -1,12 +1,11 @@
-import logging
 from pathlib import Path
+from t2wml.utils.debug_logging import basic_debug
 import pandas as pd
 
+@basic_debug
 def post_process_data(data):
-    logging.debug("enter PandasLoader post_process data")
     data = data.fillna("")
     data = data.replace(r'^\s+$', "", regex=True)
-    logging.debug("returning from PandasLoader post_process data")
     return data
 
 def load_pickle(pickle_path):
@@ -21,11 +20,11 @@ class PandasLoader:
         self.is_excel = True if self.file_extension in [".xlsx", ".xls"] else False
         self.pd_args = dict(dtype=str, header=None)
 
+    @basic_debug
     def load_sheet(self, sheet_name):
         """
         returns a single sheet's data frame
         """
-        logging.debug("enter PandasLoader.load_sheet")
         if self.is_excel:
             data = pd.read_excel(
                 self.file_path, sheet_name=sheet_name, **self.pd_args)     
@@ -36,19 +35,17 @@ class PandasLoader:
                 data = pd.read_csv(self.file_path, sep="\t", **self.pd_args)
             else: #attempt to parse type using csv sniffer
                 data = pd.read_table(self.file_path, sep=None, **self.pd_args)
-        logging.debug("returning from PandasLoader.load_sheet")
         return post_process_data(data)
     
     @property
     def non_excel_sheet_name(self):
         return Path(self.file_path).name
 
-
+    @basic_debug
     def load_file(self):
         """
         returns a dictionary of sheet_names and their data frames
         """
-        logging.debug("enter PandasLoader load_file")
         if self.is_excel:
             return_dict = {}
             loaded_file = pd.read_excel(
@@ -57,12 +54,10 @@ class PandasLoader:
                 data = loaded_file[sheet_name]
                 data = post_process_data(data)
                 return_dict[sheet_name] = data
-            logging.debug("return from PandasLoader load_file")
             return return_dict
         else:
             data = self.load_sheet(None)
             sheet_name = self.non_excel_sheet_name
-            logging.debug("return from PandasLoader load_file")
             return {sheet_name: data}
 
 
