@@ -1,7 +1,6 @@
-from t2wml.utils.debug_logging import basic_debug
+from t2wml.utils.debug_logging import basic_debug, t2wml_log
 import warnings
 import pandas
-import logging
 from datetime import datetime
 try:
     from etk.wikidata.utils import parse_datetime_string
@@ -86,7 +85,7 @@ def parse_datetime(value, additional_formats=None, precisions=None):
             raise ValueError("Failed to parse datetime string with the provided format/s")
     else: #no format specified. attempt to guess date
         if has_etk:
-            logging.debug("parse_datetime's has_etk==True")
+            t2wml_log.debug("parse_datetime's has_etk==True")
             # use this line to make etk stop harassing us with "no lang features detected" warnings
             with warnings.catch_warnings(record=True) as w:
                 datetime_string, precision = parse_datetime_string(
