@@ -1,4 +1,13 @@
 countries = {
+    "organisation of eastern caribbean states": "Q392770",
+    "organization of eastern caribbean states": "Q392770",
+    "european union": "Q458",
+    "hong kong":"Q8646",
+    "hkg":"Q8646",
+    "taiwan":"Q865",
+    "twn":"Q865",
+    "kosovo":"Q1246",
+    "ksv":"Q1246",
     "portugal": "Q45",
     "portuguese republic": "Q45",
     "pt": "Q45",
@@ -30,6 +39,7 @@ countries = {
     "bah": "Q398",
     "israel": "Q801",
     "state of israel": "Q801",
+    "israel and west bank": "Q801",
     "il": "Q801",
     "🇮🇱": "Q801",
     "holy land": "Q801",
@@ -125,6 +135,7 @@ countries = {
     "tn": "Q948",
     "🇹🇳": "Q948",
     "tun": "Q948",
+    "guinea bissau": "Q1007",
     "guinea-bissau": "Q1007",
     "republic of guinea-bissau": "Q1007",
     "🇬🇼": "Q1007",
@@ -446,6 +457,7 @@ countries = {
     "ivory coast": "Q1008",
     "republic of côte d\\'ivoire": "Q1008",
     "ci": "Q1008",
+    "cote d'ivoire": "Q1008",
     "cote d\\'ivoire": "Q1008",
     "🇨🇮": "Q1008",
     "côte d\\'ivoire": "Q1008",
@@ -582,6 +594,7 @@ countries = {
     "ge": "Q230",
     "🇬🇪": "Q230",
     "geo": "Q230",
+    "korea, north": "Q423",
     "north korea": "Q423",
     "🇰🇵": "Q423",
     "democratic people\\'s republic of korea": "Q423",
@@ -1141,6 +1154,7 @@ countries = {
     "bdi": "Q967",
     "democratic republic of the congo": "Q974",
     "drc": "Q974",
+    "congo democratic republic":  "Q974",
     "dr congo": "Q974",
     "congo-kinshasa": "Q974",
     "zaire": "Q974",
@@ -1261,9 +1275,11 @@ countries = {
     "🇮🇷": "Q794",
     "republic of iran": "Q794",
     "qatar": "Q846",
+    "qat": "Q846",
     "qa": "Q846",
     "state of qatar": "Q846",
     "🇶🇦": "Q846",
+    "korea, south": "Q884",
     "south korea": "Q884",
     "republic of korea": "Q884",
     "rok": "Q884",
