@@ -1,7 +1,6 @@
 import json
-from t2wml.utils.debug_logging import basic_debug, with_args_debug
+from t2wml.utils.debug_logging import basic_debug, with_args_debug, t2wml_log
 import pandas as pd
-import logging
 from pandas import DataFrame
 from collections import defaultdict
 from t2wml.utils.t2wml_exceptions import ItemNotFoundException
@@ -80,20 +79,32 @@ class ItemTable:
     @with_args_debug
     def update_table_from_dataframe(self, df: DataFrame):
         try:
+            t2wml_log.debug("replace na with empty string")
             df = df.fillna('')
+            t2wml_log.debug("replace regex in dataframe")
             df = df.replace(r'^\s+$', '', regex=True)
             overwritten = {}
-            for entry in df.itertuples():
+            
+            t2wml_log.debug("gathering all tuples")
+            tuples = list(df.itertuples())
+            t2wml_log.debug(f"gathered {len(tuples)} tuples")
+
+            t2wml_log.debug('Iterating over gathered tupled')
+            for (idx, entry) in enumerate(tuples):
+                t2wml_log.debug(f"entry index {idx}")
+                t2wml_log.debug("fetching fields from entry:")
                 column = entry.column
                 row = entry.row
                 value = str(entry.value)
                 context = entry.context
                 item = entry.item
+                t2wml_log.debug(f"column {column} row {row} value {value} context {context} item {item}")
                 try:
                     file = entry.file
                     sheet= entry.sheet
                 except:
                     file=sheet="" #backwards compatible for now
+                t2wml_log.debug(f" adding fields for: file {file} sheet {sheet}")
 
                 if not item:
                     raise ValueError("Item definition missing")
@@ -103,16 +114,29 @@ class ItemTable:
                         "at least one of column, row, or value must be defined")
 
                 if column != "":
+                    t2wml_log.debug("convert column to int")
                     column = int(column)
                 if row != "":
+                    t2wml_log.debug("convert row to int")
                     row = int(row)
+                t2wml_log.debug("create tuple key")
                 key = str((file, sheet, column, row, value))
+                t2wml_log.debug(f"key: {str(key)}")
+                t2wml_log.debug("check if already exists in lookup table")
                 if self.lookup_table[context].get(key):
+                    t2wml_log.debug("it does already exist")
                     overwritten[key] = self.lookup_table[context][key]
+                else:
+                    t2wml_log.debug("it doesn't already exist")
+                t2wml_log.debug("add/overwrite in lookup table")
                 self.lookup_table[context][key] = item
+                t2wml_log.debug(f"Done with iteration {idx}")
 
+            t2wml_log.debug('Exited loop')
             if len(overwritten):
+                t2wml_log.debug("print count for overwritten")
                 print("Wikifier update overwrote existing values: "+str(overwritten))
+            t2wml_log.debug('returning from function')
             return overwritten
         except Exception as e:
             print(e)
